Class: Lyra::CustomEventStoreAdapter
- Inherits:
-
Object
- Object
- Lyra::CustomEventStoreAdapter
- Defined in:
- lib/lyra/event_store_adapter.rb
Instance Method Summary collapse
-
#publish(event, stream_name:) ⇒ Object
Placeholder for custom event store implementations Users can implement their own adapter by extending this class.
- #read_all_streams ⇒ Object
- #read_stream(stream_name) ⇒ Object
- #subscribe(subscriber, to:) ⇒ Object
Instance Method Details
#publish(event, stream_name:) ⇒ Object
Placeholder for custom event store implementations Users can implement their own adapter by extending this class
56 57 58 |
# File 'lib/lyra/event_store_adapter.rb', line 56 def publish(event, stream_name:) raise NotImplementedError, "Custom event store adapter must implement #publish" end |
#read_all_streams ⇒ Object
64 65 66 |
# File 'lib/lyra/event_store_adapter.rb', line 64 def read_all_streams raise NotImplementedError, "Custom event store adapter must implement #read_all_streams" end |
#read_stream(stream_name) ⇒ Object
60 61 62 |
# File 'lib/lyra/event_store_adapter.rb', line 60 def read_stream(stream_name) raise NotImplementedError, "Custom event store adapter must implement #read_stream" end |
#subscribe(subscriber, to:) ⇒ Object
68 69 70 |
# File 'lib/lyra/event_store_adapter.rb', line 68 def subscribe(subscriber, to:) raise NotImplementedError, "Custom event store adapter must implement #subscribe" end |