Class: Lyra::Associations::PendingRecords
- Inherits:
-
Object
- Object
- Lyra::Associations::PendingRecords
- Defined in:
- lib/lyra/associations/event_aware.rb
Overview
Finds records that exist in events but not yet in the database
Class Method Summary collapse
-
.for(model_class, foreign_key, parent_id) ⇒ Array<VirtualRecord>
Find pending records for a has_many association.
Class Method Details
.for(model_class, foreign_key, parent_id) ⇒ Array<VirtualRecord>
Find pending records for a has_many association
149 150 151 152 153 |
# File 'lib/lyra/associations/event_aware.rb', line 149 def for(model_class, foreign_key, parent_id) # This is a simplified implementation # A production version would need to track pending events more efficiently [] end |